==> nspyre_drivers-0.1.2.tar.gz: nspyre_drivers-0.1.2/README.md <==
# Drivers
This is a set of Python drivers for lab instrumentation. These drivers are 
associated with [nspyre](https://nspyre.readthedocs.io/en/latest/), but are 
also suitable for general usage. Unless otherwise specified, drivers are 
provided under the terms of the MIT license.

## Installation

```bash
pip install nspyre-drivers
```

Certain drivers require extra dependencies. Those dependencies can be installed 
by specifying a tag during the install. E.g. to install the DLI pdu driver 
dependencies, use:

```bash
pip install nspyre-drivers[dli_pdu]
```

A full listing of the tags is below.

```
beaglebone
dli_pdu
oceanoptics
ximea
zaber
```

For some USB drivers on Linux, you need to grant user access to the drivers in 
order for VISA to detect them:
You should find the udev rules file in the same folder as the driver, then, e.g.:
$ sudo cp src/drivers/thorlabs/cld1010/99-thorlabs-cld1010.rules /etc/udev/rules.d/
Create a user group for the usb device access:
$ sudo groupadd usbtmc
Add any relevant users to the group:
$ usermod -aG usbtmc <myuser>
Reboot for the changes to take effect.

## Other Drivers

In order to minimize reinventing the wheel, below is a list of other sources of 
python instrument drivers. Please contribute if you find other useful sources!

[Cobolt](https://github.com/cobolt-lasers/pycobolt)

## Contributing

If you want to contribute driver code, please submit it as a 
[pull request](http://TODO). This project uses 
[poetry](https://python-poetry.org/). If your driver requires specific 
dependencies beyond those currently in use in the project, you should include 
them in the pyproject.toml file as extras. See the poetry documentation for 
specifics on how to declare these dependencies.

==> nspyre_drivers-0.1.3.tar.gz: nspyre_drivers-0.1.3/README.md <==
# Drivers
This is a set of Python drivers for lab instrumentation. These drivers are 
associated with [nspyre](https://nspyre.readthedocs.io/en/latest/), but are 
also suitable for general usage. Unless otherwise specified, drivers are 
provided under the terms of the MIT license.

## Installation

```bash
pip install nspyre-drivers
```

Certain drivers require extra dependencies. Those dependencies can be installed 
by specifying a tag during the install. E.g. to install the DLI pdu driver 
dependencies, use:

```bash
pip install nspyre-drivers[dli_pdu]
```

A full listing of the tags is below.

```
beaglebone
dli_pdu
oceanoptics
ximea
zaber
```

For some USB drivers on Linux, you need to grant user access to the drivers in 
order for VISA to detect them:
You should find the udev rules file in the same folder as the driver, then, e.g.:

```bash
sudo cp src/drivers/thorlabs/cld1010/99-thorlabs-cld1010.rules /etc/udev/rules.d/
````

Create a user group for the usb device access:

```bash
sudo groupadd usbtmc
```

Add any relevant users to the group:

```bash
usermod -aG usbtmc <myuser>
```

Reboot for the changes to take effect.

## Other Drivers

In order to minimize reinventing the wheel, below is a list of other sources of 
python instrument drivers. Please contribute if you find other useful sources!

[pycobolt](https://github.com/cobolt-lasers/pycobolt)

## Contributing

If you want to contribute driver code, please submit it as a 
[pull request](http://TODO). This project uses 
[poetry](https://python-poetry.org/). If your driver requires specific 
dependencies beyond those currently in use in the project, you should include 
them in the pyproject.toml file as extras. See the poetry documentation for 
specifics on how to declare these dependencies.
